==> gammapy_0.8.orig.tar.gz: gammapy-0.8/gammapy/utils/tutorials_test.py <==
#!/usr/bin/env python
"""
Test if IPython notebooks work.
"""
import os
import sys
import logging
from pkg_resources import working_set
from gammapy.extern.pathlib import Path
from gammapy.scripts.jupyter import notebook_test
import yaml

logging.basicConfig(level=logging.INFO)


def get_notebooks():
    """Read `notebooks.yaml` info."""
    filename = str(Path("tutorials") / "notebooks.yaml")
    with open(filename) as fh:
        notebooks = yaml.safe_load(fh)
    return notebooks


def requirement_missing(notebook):
    """Check if one of the requirements is missing."""
    if "requires" in notebook:
        if notebook["requires"] is None:
            return False
        for package in notebook["requires"].split():
            try:
                working_set.require(package)
            except Exception as ex:
                return True
    return False


def main():

    if "GAMMAPY_DATA" not in os.environ:
        logging.info("GAMMAPY_DATA environment variable not set.")
        logging.info("Running notebook tests requires this environment variable.")
        logging.info("Exiting now.")
        sys.exit()

    passed = True
    yamlfile = get_notebooks()
    dirnbs = Path("tutorials")

    for notebook in yamlfile:
        if requirement_missing(notebook):
            logging.info(
                "Skipping notebook {} because requirement is missing.".format(
                    notebook["name"]
                )
            )
            continue

        filename = notebook["name"] + ".ipynb"
        path = dirnbs / filename

        if not notebook_test(path):
            passed = False

    assert passed


if __name__ == "__main__":
    main()

==> gammapy_0.10.orig.tar.gz: gammapy-0.10/gammapy/utils/tutorials_test.py <==
"""Test if Jupyter notebooks work."""
import os
import sys
import logging
from pkg_resources import working_set
import yaml
from ..extern.pathlib import Path
from ..scripts.jupyter import notebook_test

log = logging.getLogger(__name__)


def get_notebooks():
    """Read `notebooks.yaml` info."""
    path = Path("tutorials") / "notebooks.yaml"
    with path.open() as fh:
        return yaml.safe_load(fh)


def requirement_missing(notebook):
    """Check if one of the requirements is missing."""
    if "requires" in notebook:
        if notebook["requires"] is None:
            return False
        for package in notebook["requires"].split():
            try:
                working_set.require(package)
            except Exception:
                return True
    return False


def main():
    logging.basicConfig(level=logging.INFO)

    if "GAMMAPY_DATA" not in os.environ:
        log.info("GAMMAPY_DATA environment variable not set.")
        log.info("Running notebook tests requires this environment variable.")
        log.info("Exiting now.")
        sys.exit()

    passed = True

    for notebook in get_notebooks():
        if requirement_missing(notebook):
            log.info(
                "Skipping notebook {} because requirement is missing.".format(
                    notebook["name"]
                )
            )
            continue

        filename = notebook["name"] + ".ipynb"
        path = Path("tutorials") / filename

        if not notebook_test(path):
            passed = False

    assert passed


if __name__ == "__main__":
    main()
